@@ -25,7 +25,7 @@ DEALINGS IN THE SOFTWARE.
 from __future__ import annotations
 import datetime
 
-from typing import TYPE_CHECKING, Any, Dict, Optional, List, Set, Union, Sequence, overload
+from typing import TYPE_CHECKING, Any, Dict, Optional, List, Set, Union, Sequence, overload, Literal
 
 from .enums import AutoModRuleTriggerType, AutoModRuleActionType, AutoModRuleEventType, try_enum
 from .flags import AutoModPresets
@@ -85,36 +85,81 @@ class AutoModRuleAction:
     __slots__ = ('type', 'channel_id', 'duration', 'custom_message')
 
     @overload
-    def __init__(self, *, channel_id: Optional[int] = ...) -> None:
+    def __init__(self, *, channel_id: int = ...) -> None:
         ...
 
     @overload
-    def __init__(self, *, duration: Optional[datetime.timedelta] = ...) -> None:
+    def __init__(self, *, type: Literal[AutoModRuleActionType.send_alert_message], channel_id: int = ...) -> None:
         ...
 
     @overload
-    def __init__(self, *, custom_message: Optional[str] = ...) -> None:
+    def __init__(self, *, duration: datetime.timedelta = ...) -> None:
+        ...
+
+    @overload
+    def __init__(self, *, type: Literal[AutoModRuleActionType.timeout], duration: datetime.timedelta = ...) -> None:
+        ...
+
+    @overload
+    def __init__(self, *, custom_message: str = ...) -> None:
+        ...
+
+    @overload
+    def __init__(self, *, type: Literal[AutoModRuleActionType.block_message]) -> None:
+        ...
+
+    @overload
+    def __init__(self, *, type: Literal[AutoModRuleActionType.block_message], custom_message: Optional[str] = ...) -> None:
+        ...
+
+    @overload
+    def __init__(
+        self,
+        *,
+        type: Optional[AutoModRuleActionType] = ...,
+        channel_id: Optional[int] = ...,
+        duration: Optional[datetime.timedelta] = ...,
+        custom_message: Optional[str] = ...,
+    ) -> None:
         ...
 
     def __init__(
         self,
         *,
+        type: Optional[AutoModRuleActionType] = None,
         channel_id: Optional[int] = None,
         duration: Optional[datetime.timedelta] = None,
         custom_message: Optional[str] = None,
     ) -> None:
-        self.channel_id: Optional[int] = channel_id
-        self.duration: Optional[datetime.timedelta] = duration
-        self.custom_message: Optional[str] = custom_message
-
         if sum(v is None for v in (channel_id, duration, custom_message)) < 2:
             raise ValueError('Only one of channel_id, duration, or custom_message can be passed.')
 
-        self.type: AutoModRuleActionType = AutoModRuleActionType.block_message
-        if channel_id:
+        self.type: AutoModRuleActionType
+        self.channel_id: Optional[int] = None
+        self.duration: Optional[datetime.timedelta] = None
+        self.custom_message: Optional[str] = None
+
+        if type is not None:
+            self.type = type
+        elif channel_id is not None:
             self.type = AutoModRuleActionType.send_alert_message
-        elif duration:
+        elif duration is not None:
             self.type = AutoModRuleActionType.timeout
+        else:
+            self.type = AutoModRuleActionType.block_message
+
+        if self.type is AutoModRuleActionType.send_alert_message:
+            if channel_id is None:
+                raise ValueError('channel_id cannot be None if type is send_alert_message')
+            self.channel_id = channel_id
+
+        if self.type is AutoModRuleActionType.timeout:
+            if duration is None:
+                raise ValueError('duration cannot be None set if type is timeout')
+            self.duration = duration
+
+        if self.type is AutoModRuleActionType.block_message:
+            self.custom_message = custom_message
 
     def __repr__(self) -> str:
         return f'<AutoModRuleAction type={self.type.value} channel={self.channel_id} duration={self.duration}>'
@@ -127,7 +172,11 @@ class AutoModRuleAction:
         elif data['type'] == AutoModRuleActionType.send_alert_message.value:
             channel_id = int(data['metadata']['channel_id'])
             return cls(channel_id=channel_id)
-        return cls(custom_message=data.get('metadata', {}).get('custom_message'))
+        elif data['type'] == AutoModRuleActionType.block_message.value:
+            custom_message = data.get('metadata', {}).get('custom_message')
+            return cls(type=AutoModRuleActionType.block_message, custom_message=custom_message)
+
+        return cls(type=AutoModRuleActionType.block_member_interactions)
 
     def to_dict(self) -> Dict[str, Any]:
         ret = {'type': self.type.value, 'metadata': {}}
@@ -155,7 +204,11 @@ class AutoModTrigger:
     +-----------------------------------------------+------------------------------------------------+
     | :attr:`AutoModRuleTriggerType.keyword_preset` | :attr:`presets`\, :attr:`allow_list`           |
     +-----------------------------------------------+------------------------------------------------+
-    | :attr:`AutoModRuleTriggerType.mention_spam`   | :attr:`mention_limit`                          |
+    | :attr:`AutoModRuleTriggerType.mention_spam`   | :attr:`mention_limit`,                         |
+    |                                               | :attr:`mention_raid_protection`                |
+    +-----------------------------------------------+------------------------------------------------+
+    | :attr:`AutoModRuleTriggerType.member_profile` | :attr:`keyword_filter`, :attr:`regex_patterns`,|
+    |                                               | :attr:`allow_list`                             |
     +-----------------------------------------------+------------------------------------------------+
 
     .. versionadded:: 2.0
@@ -165,8 +218,8 @@ class AutoModTrigger:
     type: :class:`AutoModRuleTriggerType`
         The type of trigger.
     keyword_filter: List[:class:`str`]
-        The list of strings that will trigger the keyword filter. Maximum of 1000.
-        Keywords can only be up to 60 characters in length.
+        The list of strings that will trigger the filter.
+        Maximum of 1000. Keywords can only be up to 60 characters in length.
 
         This could be combined with :attr:`regex_patterns`.
     regex_patterns: List[:class:`str`]
@@ -185,6 +238,10 @@ class AutoModTrigger:
     mention_limit: :class:`int`
         The total number of user and role mentions a message can contain.
         Has a maximum of 50.
+    mention_raid_protection: :class:`bool`
+        Whether mention raid protection is enabled or not.
+
+        .. versionadded:: 2.4
     """
 
     __slots__ = (
@@ -194,6 +251,7 @@ class AutoModTrigger:
         'allow_list',
         'mention_limit',
         'regex_patterns',
+        'mention_raid_protection',
     )
 
     def __init__(
@@ -205,9 +263,13 @@ class AutoModTrigger:
         allow_list: Optional[List[str]] = None,
         mention_limit: Optional[int] = None,
         regex_patterns: Optional[List[str]] = None,
+        mention_raid_protection: Optional[bool] = None,
     ) -> None:
-        if type is None and sum(arg is not None for arg in (keyword_filter or regex_patterns, presets, mention_limit)) > 1:
-            raise ValueError('Please pass only one of keyword_filter, regex_patterns, presets, or mention_limit.')
+        unique_args = (keyword_filter or regex_patterns, presets, mention_limit or mention_raid_protection)
+        if type is None and sum(arg is not None for arg in unique_args) > 1:
+            raise ValueError(
+                'Please pass only one of keyword_filter/regex_patterns, presets, or mention_limit/mention_raid_protection.'
+            )
 
         if type is not None:
             self.type = type
@@ -215,17 +277,18 @@ class AutoModTrigger:
             self.type = AutoModRuleTriggerType.keyword
         elif presets is not None:
             self.type = AutoModRuleTriggerType.keyword_preset
-        elif mention_limit is not None:
+        elif mention_limit is not None or mention_raid_protection is not None:
             self.type = AutoModRuleTriggerType.mention_spam
         else:
             raise ValueError(
-                'Please pass the trigger type explicitly if not using keyword_filter, presets, or mention_limit.'
+                'Please pass the trigger type explicitly if not using keyword_filter, regex_patterns, presets, mention_limit, or mention_raid_protection.'
             )
 
         self.keyword_filter: List[str] = keyword_filter if keyword_filter is not None else []
         self.presets: AutoModPresets = presets if presets is not None else AutoModPresets()
         self.allow_list: List[str] = allow_list if allow_list is not None else []
         self.mention_limit: int = mention_limit if mention_limit is not None else 0
+        self.mention_raid_protection: bool = mention_raid_protection if mention_raid_protection is not None else False
         self.regex_patterns: List[str] = regex_patterns if regex_patterns is not None else []
 
     def __repr__(self) -> str:
@@ -241,7 +304,7 @@ class AutoModTrigger:
         type_ = try_enum(AutoModRuleTriggerType, type)
         if data is None:
             return cls(type=type_)
-        elif type_ is AutoModRuleTriggerType.keyword:
+        elif type_ in (AutoModRuleTriggerType.keyword, AutoModRuleTriggerType.member_profile):
             return cls(
                 type=type_,
                 keyword_filter=data.get('keyword_filter'),
@@ -253,12 +316,16 @@ class AutoModTrigger:
                 type=type_, presets=AutoModPresets._from_value(data.get('presets', [])), allow_list=data.get('allow_list')
             )
         elif type_ is AutoModRuleTriggerType.mention_spam:
-            return cls(type=type_, mention_limit=data.get('mention_total_limit'))
+            return cls(
+                type=type_,
+                mention_limit=data.get('mention_total_limit'),
+                mention_raid_protection=data.get('mention_raid_protection_enabled'),
+            )
         else:
             return cls(type=type_)
 
     def to_metadata_dict(self) -> Optional[Dict[str, Any]]:
-        if self.type is AutoModRuleTriggerType.keyword:
+        if self.type in (AutoModRuleTriggerType.keyword, AutoModRuleTriggerType.member_profile):
             return {
                 'keyword_filter': self.keyword_filter,
                 'regex_patterns': self.regex_patterns,
@@ -267,7 +334,10 @@ class AutoModTrigger:
         elif self.type is AutoModRuleTriggerType.keyword_preset:
             return {'presets': self.presets.to_array(), 'allow_list': self.allow_list}
         elif self.type is AutoModRuleTriggerType.mention_spam:
-            return {'mention_total_limit': self.mention_limit}
+            return {
+                'mention_total_limit': self.mention_limit,
+                'mention_raid_protection_enabled': self.mention_raid_protection,
+            }
 
 
 class AutoModRule:
@@ -293,6 +363,8 @@ class AutoModRule:
         The IDs of the roles that are exempt from the rule.
     exempt_channel_ids: Set[:class:`int`]
         The IDs of the channels that are exempt from the rule.
+    event_type: :class:`AutoModRuleEventType`
+        The type of event that will trigger the the rule.
     """
 
     __slots__ = (
@@ -446,7 +518,7 @@ class AutoModRule:
             payload['name'] = name
 
         if event_type is not MISSING:
-            payload['event_type'] = event_type
+            payload['event_type'] = event_type.value
 
         if trigger is not MISSING:
             trigger_metadata = trigger.to_metadata_dict()
@@ -469,7 +541,7 @@ class AutoModRule:
             **payload,
         )
 
-        return AutoModRule(data=data, guild=self.guild, state=self._state)
+        return self.__class__(data=data, guild=self.guild, state=self._state)
 
     async def delete(self, *, reason: str = MISSING) -> None:
         """|coro|
