@@ -40,12 +40,48 @@ from typing import (
     Type,
     TypeVar,
     overload,
+    TypedDict,
 )
 
 from .enums import UserFlags
 
 if TYPE_CHECKING:
-    from typing_extensions import Self
+    from typing_extensions import Self, Unpack
+
+    class _IntentsFlagsKwargs(TypedDict, total=False):
+        guilds: bool
+        members: bool
+        moderation: bool
+        bans: bool
+        emojis: bool
+        emojis_and_stickers: bool
+        expressions: bool
+        integrations: bool
+        webhooks: bool
+        invites: bool
+        voice_states: bool
+        presences: bool
+        messages: bool
+        guild_messages: bool
+        dm_messages: bool
+        reactions: bool
+        guild_reactions: bool
+        dm_reactions: bool
+        typing: bool
+        guild_typing: bool
+        dm_typing: bool
+        message_content: bool
+        guild_scheduled_events: bool
+        auto_moderation: bool
+        auto_moderation_configuration: bool
+        auto_moderation_execution: bool
+        polls: bool
+        guild_polls: bool
+        dm_polls: bool
+
+    class _MemberCacheFlagsKwargs(TypedDict, total=False):
+        voice: bool
+        joined: bool
 
 
 __all__ = (
@@ -64,6 +100,7 @@ __all__ = (
     'AppInstallationType',
     'SKUFlags',
     'EmbedFlags',
+    'InviteFlags',
 )
 
 BF = TypeVar('BF', bound='BaseFlags')
@@ -499,6 +536,16 @@ class MessageFlags(BaseFlags):
         """
         return 16384
 
+    @flag_value
+    def components_v2(self):
+        """:class:`bool`: Returns ``True`` if the message has Discord's v2 components.
+
+        Does not allow sending any ``content``, ``embed``, ``embeds``, ``stickers``, or ``poll``.
+
+        .. versionadded:: 2.6
+        """
+        return 32768
+
 
 @fill_with_flags()
 class PublicUserFlags(BaseFlags):
@@ -754,12 +801,12 @@ class Intents(BaseFlags):
 
     __slots__ = ()
 
-    def __init__(self, value: int = 0, **kwargs: bool) -> None:
+    def __init__(self, value: int = 0, **kwargs: Unpack[_IntentsFlagsKwargs]) -> None:
         self.value: int = value
-        for key, value in kwargs.items():
+        for key, kwvalue in kwargs.items():
             if key not in self.VALID_FLAGS:
                 raise TypeError(f'{key!r} is not a valid flag name.')
-            setattr(self, key, value)
+            setattr(self, key, kwvalue)
 
     @classmethod
     def all(cls: Type[Intents]) -> Intents:
@@ -1415,7 +1462,7 @@ class MemberCacheFlags(BaseFlags):
 
     __slots__ = ()
 
-    def __init__(self, **kwargs: bool):
+    def __init__(self, **kwargs: Unpack[_MemberCacheFlagsKwargs]) -> None:
         bits = max(self.VALID_FLAGS.values()).bit_length()
         self.value: int = (1 << bits) - 1
         for key, value in kwargs.items():
@@ -2093,6 +2140,15 @@ class MemberFlags(BaseFlags):
         """
         return 1 << 7
 
+    @flag_value
+    def automod_quarantined_guild_tag(self):
+        """:class:`bool`: Returns ``True`` if the member's guild tag has been
+        blocked by AutoMod.
+
+        .. versionadded:: 2.6
+        """
+        return 1 << 10
+
     @flag_value
     def dm_settings_upsell_acknowledged(self):
         """:class:`bool`: Returns ``True`` if the member has dismissed the DM settings upsell.
@@ -2397,3 +2453,60 @@ class EmbedFlags(BaseFlags):
         longer displayed.
         """
         return 1 << 5
+
+
+@fill_with_flags()
+class InviteFlags(BaseFlags):
+    r"""Wraps up the Discord Invite flags
+
+    .. versionadded:: 2.6
+
+    .. container:: operations
+
+        .. describe:: x == y
+
+            Checks if two InviteFlags are equal.
+
+        .. describe:: x != y
+
+            Checks if two InviteFlags are not equal.
+
+        .. describe:: x | y, x |= y
+
+            Returns a InviteFlags instance with all enabled flags from
+            both x and y.
+
+        .. describe:: x ^ y, x ^= y
+
+            Returns a InviteFlags instance with only flags enabled on
+            only one of x or y, not on both.
+
+        .. describe:: ~x
+
+            Returns a InviteFlags instance with all flags inverted from x.
+
+        .. describe:: hash(x)
+
+            Returns the flag's hash.
+
+        .. describe:: iter(x)
+
+            Returns an iterator of ``(name, value)`` pairs. This allows it
+            to be, for example, constructed as a dict or a list of pairs.
+            Note that aliases are not shown.
+
+        .. describe:: bool(b)
+
+            Returns whether any flag is set to ``True``.
+
+    Attributes
+    ----------
+    value: :class:`int`
+        The raw value. You should query flags via the properties
+        rather than using this raw value.
+    """
+
+    @flag_value
+    def guest(self):
+        """:class:`bool`: Returns ``True`` if this is a guest invite for a voice channel."""
+        return 1 << 0
